@@ -41,26 +41,26 @@ KnightsTextView::KnightsTextView(TQWidget *parent, resource *Rsrc ) : TQTextBrow
 		Configure functions in the View right click menu
 	*/
 	menuView->insertItem( TQIconSet( Rsrc->LoadIcon( TQString("edit-copy"), TDEIcon::Small ) ),
-												i18n( "&Copy" ), this, TQT_SLOT( menuFunct(int) ), CTRL+Key_C, MENU_COPY );
-	menuView->insertItem( i18n("Select &All"), this, TQT_SLOT( menuFunct(int) ), CTRL+Key_A, MENU_SELECT_ALL );
+												i18n( "&Copy" ), this, TQ_SLOT( menuFunct(int) ), CTRL+Key_C, MENU_COPY );
+	menuView->insertItem( i18n("Select &All"), this, TQ_SLOT( menuFunct(int) ), CTRL+Key_A, MENU_SELECT_ALL );
 	menuView->insertSeparator();
 	menuView->insertItem( TQIconSet( Rsrc->LoadIcon( TQString("document-print"), TDEIcon::Small ) ),
-												i18n( "&Print" ), this, TQT_SLOT( menuFunct(int) ), CTRL+Key_P, MENU_PRINT );
+												i18n( "&Print" ), this, TQ_SLOT( menuFunct(int) ), CTRL+Key_P, MENU_PRINT );
 //  menuView->insertItem( TQIconSet( Rsrc->LoadIcon( TQString("edit-find"), TDEIcon::Small ) ),
-//                        i18n( "&Find" ), this, TQT_SLOT( menuFunct(int) ), CTRL+Key_F, MENU_FIND );
+//                        i18n( "&Find" ), this, TQ_SLOT( menuFunct(int) ), CTRL+Key_F, MENU_FIND );
 //	menuView->insertItem( TQIconSet( Rsrc->LoadIcon( TQString("next"), TDEIcon::Small ) ),
-//												i18n( "Find &Next" ), this, TQT_SLOT( menuFunct(int) ), Key_F3, MENU_FIND_NEXT );
+//												i18n( "Find &Next" ), this, TQ_SLOT( menuFunct(int) ), Key_F3, MENU_FIND_NEXT );
 //  menuView->insertSeparator();
 	menuView->insertSeparator();
 	menuView->insertItem( TQIconSet( Rsrc->LoadIcon( TQString("zoom-in"), TDEIcon::Small ) ),
-												i18n( "Zoom &In" ), this, TQT_SLOT( menuFunct(int) ), 0, MENU_ZOOM_IN );
+												i18n( "Zoom &In" ), this, TQ_SLOT( menuFunct(int) ), 0, MENU_ZOOM_IN );
 	menuView->insertItem( TQIconSet( Rsrc->LoadIcon( TQString("zoom-out"), TDEIcon::Small ) ),
-												i18n( "Zoom &Out" ), this, TQT_SLOT( menuFunct(int) ), 0, MENU_ZOOM_OUT );
+												i18n( "Zoom &Out" ), this, TQ_SLOT( menuFunct(int) ), 0, MENU_ZOOM_OUT );
 
   /* disconnect the linkClicked signal so we can replace it with our own */
-	disconnect(this, TQT_SIGNAL(linkClicked(const TQString&)),this ,0);
+	disconnect(this, TQ_SIGNAL(linkClicked(const TQString&)),this ,0);
 	/* connect the linkClicked signal to displayLink slot */
-	connect(this, TQT_SIGNAL(linkClicked(const TQString&)), this, TQT_SLOT(displayLink(const TQString&)));
+	connect(this, TQ_SIGNAL(linkClicked(const TQString&)), this, TQ_SLOT(displayLink(const TQString&)));
 
 	show();
 }
@@ -77,7 +77,7 @@ KnightsTextView::~KnightsTextView()
 ///////////////////////////////////////
 void KnightsTextView::viewportMousePressEvent( TQMouseEvent *e )
 {
-	if( e->button() == Qt::RightButton )
+	if( e->button() == TQt::RightButton )
 	{
 		emit rightButtonClicked( e->globalPos() );
 		display_menuView( e->globalPos() );
