@@ -34,7 +34,7 @@ pgn::pgn( resource *Rsrc, match_param *param )
 
 	if( Param != NULL )
 	{
-		connect( Param, TQT_SIGNAL( valuesChanged() ), this, TQT_SLOT( parseMatchParam() ) );
+		connect( Param, TQ_SIGNAL( valuesChanged() ), this, TQ_SLOT( parseMatchParam() ) );
 	}
 }
 pgn::~pgn()
@@ -45,7 +45,7 @@ pgn::~pgn()
 	{
 		if( Resource->tabManager->isTab( pgnView ) )
 		{
-			Resource->tabManager->removeTab( TQT_TQOBJECT(pgnView) );
+			Resource->tabManager->removeTab( pgnView );
 		}
 	}
 }
@@ -386,7 +386,7 @@ bool pgn::load( const int pos )
 			}
 			/* Allocate the Tab_PGNView */
 			pgnView = new tab_pgnView( this, Resource );
-			connect( pgnView, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( childViewDestroyed() ) );
+			connect( pgnView, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( childViewDestroyed() ) );
 			Resource->tabManager->addTab( pgnView, i18n( "%1 vs. %2" ).arg( TAG_White ).arg( TAG_Black ) );
 			pgnView->init();
 			File.at( File_Position );
@@ -732,7 +732,7 @@ bool pgn::open( const TQString &URL )
 		close();
 		return FALSE;
 	}
-	Input.setDevice( TQT_TQIODEVICE(&File) );
+	Input.setDevice( &File );
 	CurrentURL = URL;
 	File.at(0);
 	return TRUE;
@@ -951,7 +951,7 @@ void pgn::print( void )
 		/* Allocate the Tab_PGNView */
 		pgnView = new tab_pgnView( this, Resource );
 		Resource->tabManager->addTab( pgnView, i18n( "%1 vs. %2" ).arg( TAG_White ).arg( TAG_Black ) );
-		connect( pgnView, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( childViewDestroyed() ) );
+		connect( pgnView, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( childViewDestroyed() ) );
 		pgnView->init();
 	}
 	pgnView->print();
