@@ -46,7 +46,7 @@ proto_xboard::proto_xboard( const int ID ) : proto_base( ID )
 
 	CMDList = new CommandList;
 	InitTimer = new TQTimer( this );
-	connect( InitTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( releaseBuffer() ) );
+	connect( InitTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( releaseBuffer() ) );
 
 	Check								= TRUE;
 	Team								= FALSE;
