@@ -29,7 +29,7 @@ setPageEngines::setPageEngines(TQWidget *parent, resource *Rsrc  ) : TQVBoxLayou
 
 	/* Engines to play White */
 	GROUP_White_Current = new TQGroupBox( 3,
-																	Qt::Vertical,
+																	TQt::Vertical,
 																	i18n( "Engines to Play White" ),
 																	BOX_Current );
 
@@ -41,7 +41,7 @@ setPageEngines::setPageEngines(TQWidget *parent, resource *Rsrc  ) : TQVBoxLayou
 
 	/* Engines to play Black */
 	GROUP_Black_Current = new TQGroupBox( 3,
-																	Qt::Vertical,
+																	TQt::Vertical,
 																	i18n( "Engines to Play Black" ),
 																	BOX_Current );
 
@@ -53,7 +53,7 @@ setPageEngines::setPageEngines(TQWidget *parent, resource *Rsrc  ) : TQVBoxLayou
 
 	/* Chess Engines ListView */
 	GROUP_Engines = new TQGroupBox(	2,
-																	Qt::Horizontal,
+																	TQt::Horizontal,
 																	i18n( "Chess Engines" ),
 																	parent );
 	addWidget( GROUP_Engines );
@@ -69,7 +69,7 @@ setPageEngines::setPageEngines(TQWidget *parent, resource *Rsrc  ) : TQVBoxLayou
 	Engines_ListView->setShowSortIndicator( TRUE );
 	Engines_ListView->restoreLayout( kapp->config(), "Engines_ListView" );
 
-	Engines_ButtonBox = new KButtonBox( GROUP_Engines,Qt::Vertical );
+	Engines_ButtonBox = new KButtonBox( GROUP_Engines,TQt::Vertical );
 		Engines_Button_Add = Engines_ButtonBox->addButton( i18n( "&Add..." ) );
 		Engines_Button_Change = Engines_ButtonBox->addButton( i18n( "&Modify..." ) );
 		Engines_Button_Delete = Engines_ButtonBox->addButton( i18n( "&Delete..." ) );
@@ -77,16 +77,16 @@ setPageEngines::setPageEngines(TQWidget *parent, resource *Rsrc  ) : TQVBoxLayou
 
 	BuildEngineData();
 
-	connect( Engines_Button_Add, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEngine_Add() ) );
-	connect( Engines_Button_Change, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEngine_Modify() ) );
-	connect( Engines_Button_Delete, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEngine_Delete() ) );
-	connect( Engines_White, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( slotCurrent_White(int) ) );
-	connect( Engines_White_Book, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( slotCurrent_White_Book(int) ) );
-	connect( Engines_Black, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( slotCurrent_Black(int) ) );
-	connect( Engines_Black_Book, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( slotCurrent_Black_Book(int) ) );
-	connect( White_Use_Book, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( slotToggle_White_Book(bool) ) );
-	connect( Black_Use_Book, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( slotToggle_Black_Book(bool) ) );
-	connect( Engines_ListView, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( selectionChanged() ) );
+	connect( Engines_Button_Add, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEngine_Add() ) );
+	connect( Engines_Button_Change, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEngine_Modify() ) );
+	connect( Engines_Button_Delete, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEngine_Delete() ) );
+	connect( Engines_White, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( slotCurrent_White(int) ) );
+	connect( Engines_White_Book, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( slotCurrent_White_Book(int) ) );
+	connect( Engines_Black, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( slotCurrent_Black(int) ) );
+	connect( Engines_Black_Book, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( slotCurrent_Black_Book(int) ) );
+	connect( White_Use_Book, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( slotToggle_White_Book(bool) ) );
+	connect( Black_Use_Book, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( slotToggle_Black_Book(bool) ) );
+	connect( Engines_ListView, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( selectionChanged() ) );
 }
 setPageEngines::~setPageEngines()
 {
@@ -207,7 +207,7 @@ void setPageEngines::BuildEngineData( void )
 void setPageEngines::slotEngine_Add( void )
 {
 	Engine_Dialog = new dlg_engine( Parent, "EngineDialog", Resource );
-	connect( Engine_Dialog, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( BuildEngineData() ) );
+	connect( Engine_Dialog, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( BuildEngineData() ) );
 	emit enableApply();
 }
 ///////////////////////////////////////
@@ -223,7 +223,7 @@ void setPageEngines::slotEngine_Modify( void )
 	if( Select.isEmpty() ) return;
 	Item = Select.first();
 	Engine_Dialog = new dlg_engine( Parent, "EngineDialog", Resource, Item->text(0) );
-	connect( Engine_Dialog, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( BuildEngineData() ) );
+	connect( Engine_Dialog, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( BuildEngineData() ) );
 	emit enableApply();
 }
 ///////////////////////////////////////
