@@ -34,8 +34,8 @@ TabBox::TabBox( resource *rsrc ) : TQVBox(0,"TabBox",TQt::WDestructiveClose)
 
 	myAccel = new Accel( this, myResource->myAccel );
 
-	connect( myTabs, TQT_SIGNAL( currentChanged( TQWidget* ) ), this, TQT_SLOT( changeMyCaption( TQWidget* ) ) );
-	connect( this, TQT_SIGNAL( focus( const TQChar& ) ), myResource->myAccel, TQT_SIGNAL( focus( const TQChar& ) ) );
+	connect( myTabs, TQ_SIGNAL( currentChanged( TQWidget* ) ), this, TQ_SLOT( changeMyCaption( TQWidget* ) ) );
+	connect( this, TQ_SIGNAL( focus( const TQChar& ) ), myResource->myAccel, TQ_SIGNAL( focus( const TQChar& ) ) );
 }
 TabBox::~TabBox()
 {
@@ -78,8 +78,8 @@ void TabBox::addTab( TQWidget *child, const TQString &caption )
 		myTabs->addTab( child, caption );
 		myTabs->showPage( child );
 		changeMyCaption( child );
-		connect( child, TQT_SIGNAL( newParent( TabBox* ) ), this, TQT_SIGNAL( newTabBox( TabBox* ) ) );
-		connect( child, TQT_SIGNAL( requestDestruction() ), this, TQT_SLOT( destroyChild() ) );
+		connect( child, TQ_SIGNAL( newParent( TabBox* ) ), this, TQ_SIGNAL( newTabBox( TabBox* ) ) );
+		connect( child, TQ_SIGNAL( requestDestruction() ), this, TQ_SLOT( destroyChild() ) );
 	}
 	else
 	{
@@ -89,8 +89,8 @@ void TabBox::addTab( TQWidget *child, const TQString &caption )
 		myTabs->addTab( newPage, caption );
 		myTabs->showPage( newPage );
 		changeMyCaption( newPage );
-		connect( newPage, TQT_SIGNAL( newParent( TabBox* ) ), this, TQT_SIGNAL( newTabBox( TabBox* ) ) );
-		connect( newPage, TQT_SIGNAL( requestDestruction() ), this, TQT_SLOT( destroyChild() ) );
+		connect( newPage, TQ_SIGNAL( newParent( TabBox* ) ), this, TQ_SIGNAL( newTabBox( TabBox* ) ) );
+		connect( newPage, TQ_SIGNAL( requestDestruction() ), this, TQ_SLOT( destroyChild() ) );
 	}
 }
 ///////////////////////////////////////
